@@ -111,4 +111,15 @@ def apply_translations(form, translations=False):
             if field in translations:
                 sfield.label = translations[field]
         return form
-    return form
\ No newline at end of file
+    return form
+
+def apply_field_updates(form, lst):
+    if lst:
+        for field in form.fields:
+            sfield = form.fields[field]
+            for field_name, widget_name, attr in lst:
+                if field == field_name:
+                    sfield.widget.attrs.update({widget_name: attr})
+    return form
+        
+        
\ No newline at end of file
